@@ -46,6 +46,7 @@ class Database:
         "postgresql+aiopg": "databases.backends.aiopg:AiopgBackend",
         "postgres": "databases.backends.postgres:PostgresBackend",
         "mysql": "databases.backends.mysql:MySQLBackend",
+        "mysql+asyncmy": "databases.backends.asyncmy:AsyncMyBackend",
         "sqlite": "databases.backends.sqlite:SQLiteBackend",
     }
 
@@ -143,13 +144,13 @@ class Database:
 
     async def fetch_all(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.List[typing.Mapping]:
+    ) -> typing.List[typing.Sequence]:
         async with self.connection() as connection:
             return await connection.fetch_all(query, values)
 
     async def fetch_one(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.Optional[typing.Mapping]:
+    ) -> typing.Optional[typing.Sequence]:
         async with self.connection() as connection:
             return await connection.fetch_one(query, values)
 
@@ -221,10 +222,9 @@ class Database:
             self._force_rollback = initial
 
     def _get_backend(self) -> str:
-        try:
-            return self.SUPPORTED_BACKENDS[self.url.scheme]
-        except KeyError:
-            return self.SUPPORTED_BACKENDS[self.url.dialect]
+        return self.SUPPORTED_BACKENDS.get(
+            self.url.scheme, self.SUPPORTED_BACKENDS[self.url.dialect]
+        )
 
 
 class Connection:
@@ -265,14 +265,14 @@ class Connection:
 
     async def fetch_all(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.List[typing.Mapping]:
+    ) -> typing.List[typing.Sequence]:
         built_query = self._build_query(query, values)
         async with self._query_lock:
             return await self._connection.fetch_all(built_query)
 
     async def fetch_one(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.Optional[typing.Mapping]:
+    ) -> typing.Optional[typing.Sequence]:
         built_query = self._build_query(query, values)
         async with self._query_lock:
             return await self._connection.fetch_one(built_query)
@@ -473,7 +473,11 @@ class DatabaseURL:
 
     @property
     def hostname(self) -> typing.Optional[str]:
-        return self.components.hostname
+        return (
+            self.components.hostname
+            or self.options.get("host")
+            or self.options.get("unix_sock")
+        )
 
     @property
     def port(self) -> typing.Optional[int]:
